SPARSE BATCHED -- KokkosKernels sparse batched functor-level interfaces
=======================================================================

cg
--
.. doxygenstruct:: KokkosBatched::CG
    :members:

crsmatrix
---------
.. doxygenclass:: KokkosBatched::CrsMatrix
    :members:

gmres
-----
.. doxygenstruct:: KokkosBatched::GMRES
    :members:

identity
--------
.. doxygenclass:: KokkosBatched::Identity
    :members:

jacobiprec
----------
.. doxygenclass:: KokkosBatched::JacobiPrec
    :members:

krylovhandle
------------
.. doxygenclass:: KokkosBatched::KrylovHandle
    :members:

spmv
----
.. doxygenstruct:: KokkosBatched::SerialSpmv
    :members:
.. doxygenstruct:: KokkosBatched::TeamSpmv
    :members:
.. doxygenstruct:: KokkosBatched::TeamVectorSpmv
    :members:
.. doxygenstruct:: KokkosBatched::Spmv
    :members: